# filename: __init__.py
# @Time    : 2025/12/18 16:07
# @Author  : JQQ
# @Email   : jqq1716@gmail.com
# @Software: PyCharm

"""MCP 工具集合 | MCP tools."""

from office4ai.a2c_smcp.tools.base import BaseTool

__all__ = [
    "BaseTool",
]
